==> azureus_3.1.1.0.orig.tar.gz: azureus-3.1.1.0.orig/com/aelitis/azureus/core/util/average/RunningAverage.java <==
/*
 * Created on Oct 08, 2004
 * Created by Alon Rohter
 * Copyright (C) 2004, 2005, 2006 Aelitis, All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 * AELITIS, SAS au capital de 46,603.30 euros
 * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
 *
 */
package com.aelitis.azureus.core.util.average;

/**
 * Implements a simple running average.
 */
public class RunningAverage implements Average {
  
   private long count = 0;
   private double sum;
   
   /**
    * Create a new running average.
    */
   public RunningAverage() {
      this.sum = 0;
   }
   
	public void reset(){
		count = 0;
		sum = 0;
	}
   /**
    * Update average and return average-so-far.
    */
   public double update(final double newValue) {
      sum += newValue;
      count++;
      return sum / count;
   }

   /**
    * Return average-so-far.
    */
   public double getAverage() { return sum / count; }

}

==> azureus_4.3.0.6.orig.tar.gz: azureus-4.3.0.6/com/aelitis/azureus/core/util/average/RunningAverage.java <==
/*
 * Created on Oct 08, 2004
 * Created by Alon Rohter
 * Copyright (C) 2004, 2005, 2006 Aelitis, All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 * AELITIS, SAS au capital de 46,603.30 euros
 * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
 *
 */
package com.aelitis.azureus.core.util.average;

/**
 * Implements a simple running average.
 */
public class RunningAverage implements Average {
  
   private long count = 0;
   private double sum;
   
   /**
    * Create a new running average.
    */
   public RunningAverage() {
      this.sum = 0;
   }
   
	public void reset(){
		count = 0;
		sum = 0;
	}
   /**
    * Update average and return average-so-far.
    */
   public double update(final double newValue) {
      sum += newValue;
      count++;
      return sum / count;
   }

   /**
    * Return average-so-far.
    */
   public double getAverage() { return count==0?0:(sum / count ); }

}
